ScannerConfig class

Configuration for the scanner UI

Constructors

ScannerConfig({Color borderColor = Colors.green, double borderWidth = 3.0, double borderRadius = 16.0, double scanAreaSize = 0.7, Color overlayColor = Colors.black54, bool showStatusText = true, String? title, bool showAppBar = true, Color? appBarColor, bool showTorchToggle = true})
const

Properties

appBarColor Color?
AppBar background color
final
borderColor Color
Color of the scan area border
final
borderRadius double
Border radius of the scan area
final
borderWidth double
Width of the scan area border
final
hashCode int
The hash code for this object.
no setterinherited
overlayColor Color
Background color of the overlay
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanAreaSize double
Size of the scan area as a fraction of screen width (0.0 to 1.0)
final
showAppBar bool
Show AppBar
final
showStatusText bool
Show status text
final
showTorchToggle bool
Show torch toggle button
final
title String?
AppBar title
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited